<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es" sourcelanguage="en">
<context>
    <name>AvancedQFile</name>
    <message>
        <location filename="../../AvancedQFile.cpp" line="26"/>
        <location filename="../../AvancedQFile.cpp" line="57"/>
        <location filename="../../AvancedQFile.cpp" line="88"/>
        <source>Not supported on this platform</source>
        <translation>No es compatible con esta plataforma</translation>
    </message>
    <message>
        <location filename="../../AvancedQFile.cpp" line="40"/>
        <source>Last modified date is wrong</source>
        <translation>Fecha de última modificación es incorrecto</translation>
    </message>
    <message>
        <location filename="../../AvancedQFile.cpp" line="71"/>
        <source>Last access date is wrong</source>
        <translation>Fecha de último acceso es incorrecto</translation>
    </message>
    <message>
        <location filename="../../AvancedQFile.cpp" line="121"/>
        <source>Unknown error: %1</source>
        <translation>Error desconocido: %1</translation>
    </message>
    <message>
        <location filename="../../AvancedQFile.cpp" line="187"/>
        <source>Unknown error</source>
        <translation>Error desconocido</translation>
    </message>
    <message>
        <location filename="../../AvancedQFile.cpp" line="133"/>
        <source>Path conversion error</source>
        <translation>Error de conversión de Sendero</translation>
    </message>
</context>
<context>
    <name>CopyEngine</name>
    <message>
        <location filename="../../CopyEngine.cpp" line="429"/>
        <location filename="../../CopyEngine.cpp" line="451"/>
        <source>The engine is forced to move, you can&apos;t copy with it</source>
        <translation>El motor se ve obligado a moverse, no se puede copiar con ella</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="462"/>
        <location filename="../../CopyEngine.cpp" line="484"/>
        <source>The engine is forced to copy, you can&apos;t move with it</source>
        <translation>El motor se ve obligado a copiar, no te puedes mover con él</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="508"/>
        <source>Destination</source>
        <translation>Destino</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="508"/>
        <source>Use the actual destination &quot;%1&quot;?</source>
        <translation>Utilice el destino &quot;%1&quot; actual?</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="732"/>
        <source>The mode has been forced previously. This is an internal error, please report it</source>
        <translation>El modo se ha visto obligado previamente. Este es un error interno, por favor repórtelo</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1062"/>
        <location filename="../../CopyEngine.cpp" line="1065"/>
        <location filename="../../CopyEngine.cpp" line="1070"/>
        <location filename="../../CopyEngine.cpp" line="1074"/>
        <source>Ask</source>
        <translation>Pedir</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1063"/>
        <location filename="../../CopyEngine.cpp" line="1067"/>
        <location filename="../../CopyEngine.cpp" line="1071"/>
        <location filename="../../CopyEngine.cpp" line="1075"/>
        <source>Skip</source>
        <translation>Omitir</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1066"/>
        <source>Merge</source>
        <translation>Unir</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1068"/>
        <location filename="../../CopyEngine.cpp" line="1080"/>
        <source>Rename</source>
        <translation>Cambiar el nombre</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1072"/>
        <source>Put at the end</source>
        <translation>Ponga al final</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1076"/>
        <source>Overwrite</source>
        <translation>Sobrescribir</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1077"/>
        <source>Overwrite if different</source>
        <translation>Sobrescribir si es diferente</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1078"/>
        <source>Overwrite if newer</source>
        <translation>Sobrescribir si nuevo</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1079"/>
        <source>Overwrite if older</source>
        <translation>Sobrescribir si es mayor</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1082"/>
        <source>Automatic</source>
        <translation>Automático</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1083"/>
        <source>Sequential</source>
        <translation>Secuencial</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1084"/>
        <source>Parallel</source>
        <translation>Paralelo</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1185"/>
        <source>Options error</source>
        <translation>error Opciones</translation>
    </message>
    <message>
        <location filename="../../CopyEngine.cpp" line="1185"/>
        <source>Options engine is not loaded. Unable to access the filters</source>
        <translation>Opciones del motor no está cargado. No es posible acceder a los filtros</translation>
    </message>
</context>
<context>
    <name>CopyEngineFactory</name>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="427"/>
        <location filename="../../CopyEngineFactory.cpp" line="430"/>
        <location filename="../../CopyEngineFactory.cpp" line="435"/>
        <location filename="../../CopyEngineFactory.cpp" line="439"/>
        <source>Ask</source>
        <translation>Pedir</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="428"/>
        <location filename="../../CopyEngineFactory.cpp" line="432"/>
        <location filename="../../CopyEngineFactory.cpp" line="436"/>
        <location filename="../../CopyEngineFactory.cpp" line="440"/>
        <source>Skip</source>
        <translation>Omitir</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="431"/>
        <source>Merge</source>
        <translation>Unir</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="433"/>
        <location filename="../../CopyEngineFactory.cpp" line="445"/>
        <source>Rename</source>
        <translation>Cambiar el nombre</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="437"/>
        <source>Put at the end</source>
        <translation>Ponga al final</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="441"/>
        <source>Overwrite</source>
        <translation>Sobrescribir</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="442"/>
        <source>Overwrite if different</source>
        <translation>Sobrescribir si es diferente</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="443"/>
        <source>Overwrite if newer</source>
        <translation>Sobrescribir si nuevo</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="444"/>
        <source>Overwrite if older</source>
        <translation>Sobrescribir si es mayor</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="447"/>
        <source>Automatic</source>
        <translation>Automático</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="448"/>
        <source>Sequential</source>
        <translation>Secuencial</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="449"/>
        <source>Parallel</source>
        <translation>Paralelo</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="500"/>
        <location filename="../../CopyEngineFactory.cpp" line="539"/>
        <source>Options error</source>
        <translation>error Opciones</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="500"/>
        <source>Options engine is not loaded. Unable to access the filters</source>
        <translation>Opciones del motor no está cargado. No es posible acceder a los filtros</translation>
    </message>
    <message>
        <location filename="../../CopyEngineFactory.cpp" line="539"/>
        <source>Options engine is not loaded, can&apos;t access to the filters</source>
        <translation>Opciones del motor no está cargado, no se puede acceder a los filtros</translation>
    </message>
</context>
<context>
    <name>DiskSpace</name>
    <message>
        <location filename="../../DiskSpace.ui" line="14"/>
        <source>Disk space</source>
        <translation>Espacio en disco</translation>
    </message>
    <message>
        <location filename="../../DiskSpace.ui" line="24"/>
        <source>You need more space on this drive to finish this transfer</source>
        <translation>Necesita más espacio en esta unidad para terminar esta transferencia</translation>
    </message>
    <message>
        <location filename="../../DiskSpace.ui" line="49"/>
        <source>Continue</source>
        <translation>Continuar</translation>
    </message>
    <message>
        <location filename="../../DiskSpace.ui" line="56"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../../DiskSpace.cpp" line="23"/>
        <source>Drives %1 have %2 available but need %3</source>
        <translation>Drives %1 tienen %2 disponible, pero necesitan %3</translation>
    </message>
</context>
<context>
    <name>FileErrorDialog</name>
    <message>
        <location filename="../../FileErrorDialog.cpp" line="54"/>
        <source>Error on folder</source>
        <translation>Error en la carpeta</translation>
    </message>
    <message>
        <location filename="../../FileErrorDialog.cpp" line="57"/>
        <source>Folder name</source>
        <translation>Nombre de la carpeta</translation>
    </message>
</context>
<context>
    <name>FileExistsDialog</name>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="137"/>
        <source>%name% - copy%suffix%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="144"/>
        <source>%name% - copy (%number%)%suffix%</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="228"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../../FileExistsDialog.cpp" line="228"/>
        <source>Try rename with using special characters</source>
        <translation>Trate de cambiar el nombre con el uso de caracteres especiales</translation>
    </message>
</context>
<context>
    <name>FileIsSameDialog</name>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="111"/>
        <source>%name% - copy</source>
        <translation type="unfinished">%name% - copia</translation>
    </message>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="118"/>
        <source>%name% - copy (%number%)</source>
        <translation type="unfinished">%name% - copia (%number%)</translation>
    </message>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="184"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../../FileIsSameDialog.cpp" line="184"/>
        <source>Try rename with using special characters</source>
        <translation>Trate de cambiar el nombre con el uso de caracteres especiales</translation>
    </message>
</context>
<context>
    <name>FilterRules</name>
    <message>
        <location filename="../../FilterRules.ui" line="33"/>
        <source>Search:</source>
        <translation>Buscar:</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="43"/>
        <source>Search type:</source>
        <translation>Tipo de búsqueda:</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="51"/>
        <source>Raw text</source>
        <translation>texto Fuente</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="56"/>
        <source>Simplified regex</source>
        <translation>Regex simplificado</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="61"/>
        <source>Perl&apos;s regex</source>
        <translation>Perl&apos;s regex</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="69"/>
        <source>Apply on:</source>
        <translation>Aplicar sobre:</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="77"/>
        <source>File</source>
        <translation>Archivos</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="82"/>
        <source>Folder</source>
        <translation>Carpeta</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="87"/>
        <source>File and folder</source>
        <translation>Archivos y carpeta</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="125"/>
        <source>The test string matches with the regex</source>
        <translation>La cadena de prueba coincide con la expresión regular</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="102"/>
        <source>Checking</source>
        <translation>Verification</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="115"/>
        <source>Test string:</source>
        <translation>Prueba de la cuerda:</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="17"/>
        <source>Filters dialog</source>
        <translation>Filtros de diálogo</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="95"/>
        <source>Whole string must match</source>
        <translation>Todo cadena debe coincidir</translation>
    </message>
    <message>
        <location filename="../../FilterRules.ui" line="108"/>
        <source>The regex is valid</source>
        <translation>La expresión regular es válido</translation>
    </message>
</context>
<context>
    <name>Filters</name>
    <message>
        <location filename="../../Filters.ui" line="14"/>
        <source>Filters</source>
        <translation>Filtros</translation>
    </message>
    <message>
        <location filename="../../Filters.ui" line="30"/>
        <source>Exclusion filters</source>
        <translation>Filtros de exclusión</translation>
    </message>
    <message>
        <location filename="../../Filters.ui" line="93"/>
        <source>Inclusion filters</source>
        <translation>Filtros de inclusión</translation>
    </message>
    <message>
        <location filename="../../Filters.ui" line="105"/>
        <source>None = Include all</source>
        <translation>Ninguno = Incluya todos los</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="93"/>
        <location filename="../../Filters.cpp" line="131"/>
        <source>Raw text</source>
        <translation>texto Fuente</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="96"/>
        <location filename="../../Filters.cpp" line="134"/>
        <source>Simplified regex</source>
        <translation>Simplificado regex</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="99"/>
        <location filename="../../Filters.cpp" line="137"/>
        <source>Perl&apos;s regex</source>
        <translation>Perl&apos;s regex</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="107"/>
        <location filename="../../Filters.cpp" line="145"/>
        <source>Only on file</source>
        <translation>Sólo en el archivo</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="110"/>
        <location filename="../../Filters.cpp" line="148"/>
        <source>Only on folder</source>
        <translation>Sólo en la carpeta</translation>
    </message>
    <message>
        <location filename="../../Filters.cpp" line="116"/>
        <location filename="../../Filters.cpp" line="154"/>
        <location filename="../../Filters.cpp" line="216"/>
        <location filename="../../Filters.cpp" line="255"/>
        <source>Full match</source>
        <translation>Partido completo</translation>
    </message>
</context>
<context>
    <name>FolderExistsDialog</name>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="57"/>
        <source>Folder already exists</source>
        <translation>Carpeta ya existe</translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="122"/>
        <source>%name% - copy</source>
        <translation type="unfinished">%name% - copia</translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="131"/>
        <source>%name% - copy (%number%)</source>
        <translation type="unfinished">%name% - copia (%number%)</translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="190"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../../FolderExistsDialog.cpp" line="190"/>
        <source>Try rename with using special characters</source>
        <translation>Trate de cambiar el nombre con el uso de caracteres especiales</translation>
    </message>
</context>
<context>
    <name>ListThread</name>
    <message>
        <location filename="../../ListThread.cpp" line="1487"/>
        <location filename="../../ListThread.cpp" line="2419"/>
        <source>Unable do to move or copy item into wrong forced mode: %1</source>
        <translation>No se puede hacer para mover o copiar elemento en modo incorrecto obligado: %1</translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1494"/>
        <location filename="../../ListThread.cpp" line="2426"/>
        <source>Unable to save the transfer list: %1</source>
        <translation>No se puede guardar la lista de transferencias: %1</translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1510"/>
        <source>Problem reading file, or file-size is 0</source>
        <translation>Problema al leer el archivo o archivos de tamaño es 0</translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1517"/>
        <source>Wrong header: &quot;%1&quot;</source>
        <translation>Encabezado incorrecto: &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1526"/>
        <source>The transfer list is in mixed mode, but this instance is not in this mode</source>
        <translation>La lista de transferencia está en modo mixto, pero este caso no es de este modo</translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1535"/>
        <source>The transfer list is in copy mode, but this instance is not in this mode</source>
        <translation>La lista de transferencia está en el modo de copia, pero esta instancia no está en este modo</translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1541"/>
        <source>The transfer list is in move mode, but this instance is not in this mode</source>
        <translation>La lista de transferencia es el modo de desplazamiento, pero esta instancia no está en este modo</translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1604"/>
        <source>Some errors have been found during the line parsing</source>
        <translation>Algunos errores han sido encontrados durante el análisis de línea</translation>
    </message>
    <message>
        <location filename="../../ListThread.cpp" line="1612"/>
        <source>Unable to open the transfer list: %1</source>
        <translation>No se puede abrir la lista de transferencias: %1</translation>
    </message>
</context>
<context>
    <name>MkPath</name>
    <message>
        <location filename="../../MkPath.cpp" line="142"/>
        <source>Unable to create the folder</source>
        <translation>No se puede crear la carpeta</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="155"/>
        <source>The source folder don&apos;t exists</source>
        <translation>La carpeta de origen no existe</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="183"/>
        <source>Unable to temporary rename the folder</source>
        <translation>No es posible cambiar el nombre de la carpeta temporal</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="206"/>
        <source>Unable to do the final real move the folder</source>
        <translation>No se puede hacer el movimiento final real de la carpeta</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="233"/>
        <source>Unable to move the folder</source>
        <translation>No se puede mover la carpeta</translation>
    </message>
    <message>
        <location filename="../../MkPath.cpp" line="93"/>
        <location filename="../../MkPath.cpp" line="276"/>
        <source>Unable to remove</source>
        <translation>No se puede eliminar</translation>
    </message>
</context>
<context>
    <name>ReadThread</name>
    <message>
        <location filename="../../ReadThread.cpp" line="59"/>
        <source>Internal error, please report it!</source>
        <translation>Error interno, por favor informe de ello!</translation>
    </message>
    <message>
        <location filename="../../ReadThread.cpp" line="188"/>
        <source>Internal error reading the source file:block size out of range</source>
        <translation>Error interno de leer el archivo de origen: tamaño de bloque fuera de rango</translation>
    </message>
    <message>
        <location filename="../../ReadThread.cpp" line="196"/>
        <location filename="../../ReadThread.cpp" line="420"/>
        <source>Unable to read the source file: </source>
        <translation>No se puede leer el archivo de origen: </translation>
    </message>
    <message>
        <location filename="../../ReadThread.cpp" line="237"/>
        <location filename="../../ReadThread.cpp" line="468"/>
        <source>File truncated during the read, possible data change</source>
        <translation>Archivo truncada durante el cambio de lectura, los datos posibles</translation>
    </message>
</context>
<context>
    <name>RenamingRules</name>
    <message>
        <location filename="../../RenamingRules.ui" line="35"/>
        <source>First renaming</source>
        <translation>En primer lugar el cambio de nombre</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="41"/>
        <source>%name% - copy%suffix%</source>
        <extracomment>%name% should not be translated</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="57"/>
        <source>%name% - copy (%number%)%suffix%</source>
        <extracomment>%name%, %number% should not be translated</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="67"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Variables: &lt;span style=&quot; font-weight:600;&quot;&gt;%name%&lt;/span&gt; for the original file name, &lt;span style=&quot; font-weight:600;&quot;&gt;%number%&lt;/span&gt; for the extra number, &lt;span style=&quot; font-weight:600;&quot;&gt;%suffix%&lt;/span&gt; file suffix&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <extracomment>%name%, %number% should not be translated</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="51"/>
        <source>Second renaming</source>
        <translation>En segundo lugar el cambio de nombre</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.cpp" line="39"/>
        <location filename="../../RenamingRules.cpp" line="62"/>
        <source>%1 - copy</source>
        <translation>%1 - copia</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.cpp" line="43"/>
        <location filename="../../RenamingRules.cpp" line="73"/>
        <source>%1 - copy (%2)</source>
        <translation>%1 - copia (%2)</translation>
    </message>
    <message>
        <location filename="../../RenamingRules.ui" line="14"/>
        <source>Renaming rules</source>
        <translation>Reglas de Cambio de nombre</translation>
    </message>
</context>
<context>
    <name>ScanFileOrFolder</name>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="274"/>
        <source>Blacklisted folder</source>
        <translation>Carpeta de la lista negra</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="338"/>
        <source>%1 - copy</source>
        <translation>%1 - copia</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="345"/>
        <source>%1 - copy (%2)</source>
        <translation>%1 - copia (%2)</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="401"/>
        <source>%name% - copy</source>
        <translation type="unfinished">%name% - copia</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="408"/>
        <source>%name% - copy (%number%)</source>
        <translation type="unfinished">%name% - copia (%number%)</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="444"/>
        <source>This is not a folder</source>
        <translation>Esto no es una carpeta</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="446"/>
        <source>The folder does exists</source>
        <translation>La carpeta no existe</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="448"/>
        <source>The folder is not readable</source>
        <translation>La carpeta no se puede leer</translation>
    </message>
    <message>
        <location filename="../../ScanFileOrFolder.cpp" line="459"/>
        <source>Problem with name encoding</source>
        <translation>Problema con codificación de nombres</translation>
    </message>
</context>
<context>
    <name>TransferThread</name>
    <message>
        <location filename="../../TransferThread.cpp" line="244"/>
        <location filename="../../TransferThread.cpp" line="673"/>
        <location filename="../../TransferThread.cpp" line="745"/>
        <location filename="../../TransferThread.cpp" line="1315"/>
        <source>File not found</source>
        <translation>Archivo no encontrado</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="346"/>
        <location filename="../../TransferThread.cpp" line="363"/>
        <source>Wrong modification date or unable to get it, you can disable time transfer to do it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="421"/>
        <location filename="../../TransferThread.cpp" line="444"/>
        <source>Internal error: Already opening</source>
        <translation type="unfinished">Error interno: Ya la apertura</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="586"/>
        <source>Drive %1</source>
        <translation type="unfinished">Drive %1</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="588"/>
        <source>Unknown folder</source>
        <translation type="unfinished">Desconocido carpeta</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="592"/>
        <source>root</source>
        <translation type="unfinished">raíz</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="787"/>
        <source>The source doesn&apos;t exist</source>
        <translation type="unfinished">La fuente no existe</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="1315"/>
        <location filename="../../TransferThread.cpp" line="1333"/>
        <location filename="../../TransferThread.cpp" line="1348"/>
        <source>Unable to change the date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="711"/>
        <location filename="../../TransferThread.cpp" line="826"/>
        <source>The source file doesn&apos;t exist</source>
        <translation type="unfinished">El archivo de origen no existe</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="1134"/>
        <source>The checksums do not match</source>
        <translation type="unfinished">Las sumas de comprobación no coinciden</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="1239"/>
        <source>Internal error: The size transfered doesn&apos;t match</source>
        <translation type="unfinished">Error interno: El tamaño transferido no coincide</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="751"/>
        <location filename="../../TransferThread.cpp" line="838"/>
        <source>Unable to do the folder</source>
        <translation type="unfinished">Incapaz de hacer la carpeta</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="228"/>
        <source>Try rename with using special characters</source>
        <translation>Trate de cambiar el nombre con el uso de caracteres especiales</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="645"/>
        <source>%name% - copy</source>
        <translation type="unfinished">%name% - copia</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="652"/>
        <source>%name% - copy (%number%)</source>
        <translation type="unfinished">%name% - copia (%number%)</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="832"/>
        <source>Another file exists at same place</source>
        <translation type="unfinished">Otro archivo existe en el mismo lugar</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="1224"/>
        <source>Internal error: The destination is not closed</source>
        <translation type="unfinished">Error interno: El destino no está cerrado</translation>
    </message>
    <message>
        <location filename="../../TransferThread.cpp" line="1250"/>
        <source>Internal error: The buffer is not empty</source>
        <translation type="unfinished">Error interno: El buffer no está vacío</translation>
    </message>
</context>
<context>
    <name>WriteThread</name>
    <message>
        <location filename="../../WriteThread.cpp" line="83"/>
        <source>Path resolution error (Empty path)</source>
        <translation>Error de resolución de ruta (camino vacío)</translation>
    </message>
    <message>
        <location filename="../../WriteThread.cpp" line="277"/>
        <source>Internal error, please report it!</source>
        <translation>Error interno, por favor informe de ello!</translation>
    </message>
    <message>
        <location filename="../../WriteThread.cpp" line="680"/>
        <source>Unable to read the source file: </source>
        <translation>No se puede leer el archivo de origen: </translation>
    </message>
    <message>
        <location filename="../../WriteThread.cpp" line="705"/>
        <source>File truncated during read, possible data change</source>
        <translation>Archivo truncado durante lectura, posible cambio de datos</translation>
    </message>
</context>
<context>
    <name>copyEngineOptions</name>
    <message>
        <location filename="../../copyEngineOptions.ui" line="44"/>
        <source>Transfer</source>
        <translation>Transferencia</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="53"/>
        <source>Move the whole folder</source>
        <translation>Mueva la carpeta completa</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="60"/>
        <source>Transfer the file rights</source>
        <translation>Transferencia de los derechos de archivo</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="70"/>
        <source>Keep the file date</source>
        <translation>Mantener la fecha de archivo</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="83"/>
        <source>Autostart the transfer</source>
        <translation>Inicio automático de la transferencia</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="90"/>
        <location filename="../../copyEngineOptions.ui" line="110"/>
        <source>Less performance if checked</source>
        <translation>Si comprueba Menos rendimiento</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="113"/>
        <source>Follow the strict order</source>
        <translation>Siga el orden estricto</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="139"/>
        <source>Error and collision</source>
        <translation>Error y de la colisión</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="145"/>
        <source>When folder error</source>
        <translation>Cuando el error carpeta</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="155"/>
        <source>When file error</source>
        <translation>Cuando archivo error</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="181"/>
        <source>When file collision</source>
        <translation>Cuando archivo colisión</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="241"/>
        <source>When folder collision</source>
        <translation>Cuando la colisión carpeta</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="272"/>
        <source>Check if destination folder exists</source>
        <translation>Compruebe si existe la carpeta de destino</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="279"/>
        <source>Renaming rules</source>
        <translation>Reglas de Cambio de nombre</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="299"/>
        <source>Delete partially transferred files</source>
        <translation>Eliminar archivos parcialmente transferidos</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="312"/>
        <source>Rename the original destination</source>
        <translation>Cambie el nombre del destino original</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="343"/>
        <source>Control</source>
        <translation>Controlar</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="349"/>
        <source>Checksum</source>
        <translation>Suma de comprobación</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="358"/>
        <source>Only after error</source>
        <translation>Sólo después de un error</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="365"/>
        <source>Ignore if impossible</source>
        <translation>No haga caso si no es posible</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="382"/>
        <source>Verify checksums</source>
        <translation>Verifique checksums</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="414"/>
        <source>Performance</source>
        <translation>Rendimiento</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="420"/>
        <source>Parallel buffer</source>
        <translation>Búfer paralelo</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="427"/>
        <location filename="../../copyEngineOptions.ui" line="440"/>
        <location filename="../../copyEngineOptions.ui" line="453"/>
        <location filename="../../copyEngineOptions.ui" line="490"/>
        <location filename="../../copyEngineOptions.ui" line="559"/>
        <source>KB</source>
        <translation>KB</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="469"/>
        <source>Block size</source>
        <translation>Tamaño del bloque</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="476"/>
        <source>Sequential buffer</source>
        <translation>Tampón secuencial</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="483"/>
        <source>Enable OS buffer</source>
        <translation>Habilitar el OS de amortiguación</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="506"/>
        <source>OS buffer only if smaller than</source>
        <translation>OS de amortiguación sólo si menor que</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="513"/>
        <source>Transfer algorithm</source>
        <translation>Algoritmo de transferencia</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="552"/>
        <source>Parallelize if smaller than</source>
        <translation>Paralelice si más pequeño que</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="582"/>
        <source>Inode threads (unsafe &gt; 1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="589"/>
        <location filename="../../copyEngineOptions.ui" line="599"/>
        <source>More cpu, but better organisation on the disk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="602"/>
        <source>Order the list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="618"/>
        <source>Misc</source>
        <translation>Misc</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="624"/>
        <source>Check the disk space</source>
        <translation>Compruebe el espacio en disco</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="634"/>
        <source>Use this folder when destination is not set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="646"/>
        <source>Browse</source>
        <translation>Busque</translation>
    </message>
    <message>
        <location filename="../../copyEngineOptions.ui" line="668"/>
        <source>Filters</source>
        <translation>Filtros</translation>
    </message>
</context>
<context>
    <name>fileErrorDialog</name>
    <message>
        <location filename="../../fileErrorDialog.ui" line="14"/>
        <source>Error with file</source>
        <translation>Error con el archivo</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="20"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="59"/>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="76"/>
        <source>Modified</source>
        <translation>Modificado</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="93"/>
        <source>File name</source>
        <translation>Nombre de archivo</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="110"/>
        <source>Destination</source>
        <translation>Destino</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="127"/>
        <source>Folder</source>
        <translation>Carpeta</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="173"/>
        <source>&amp;Always perform this action</source>
        <translation>&amp;Siempre realice esta acción</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="193"/>
        <source>Try in with elevated privileges</source>
        <translation>Pruebe con privilegios elevados</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="200"/>
        <source>Put to bottom</source>
        <translation>Ponga a abajo</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="207"/>
        <source>Retry</source>
        <translation>Reintentar</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="214"/>
        <source>&amp;Skip</source>
        <translation>&amp;Omitir</translation>
    </message>
    <message>
        <location filename="../../fileErrorDialog.ui" line="221"/>
        <source>&amp;Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>fileExistsDialog</name>
    <message>
        <location filename="../../fileExistsDialog.ui" line="14"/>
        <source>The file exists</source>
        <translation>El archivo ya existe</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="34"/>
        <source>Source</source>
        <translation>Fuente</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="50"/>
        <source>Destination</source>
        <translation>Destino</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="82"/>
        <location filename="../../fileExistsDialog.ui" line="170"/>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="99"/>
        <location filename="../../fileExistsDialog.ui" line="187"/>
        <source>Modified</source>
        <translation>Modificado</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="116"/>
        <location filename="../../fileExistsDialog.ui" line="204"/>
        <source>File name</source>
        <translation>Nombre de archivo</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="133"/>
        <location filename="../../fileExistsDialog.ui" line="221"/>
        <source>Folder</source>
        <translation>Carpeta</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="277"/>
        <source>Suggest new &amp;name</source>
        <translation>Sugerir nuevo &amp;nombre</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="288"/>
        <source>&amp;Always perform this action</source>
        <translation>&amp;Siempre realice esta acción</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="346"/>
        <location filename="../../fileExistsDialog.ui" line="349"/>
        <source>Overwrite if modification date differs</source>
        <translation>Sobrescribir si la fecha de modificación difiere</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="308"/>
        <source>&amp;Rename</source>
        <translation>&amp;Cambiar el nombre</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="315"/>
        <source>&amp;Overwrite</source>
        <translation>&amp;Sobrescribir</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="325"/>
        <source>&amp;Skip</source>
        <translation>&amp;Omitir</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="332"/>
        <source>&amp;Cancel</source>
        <translation>Ca&amp;ncelar</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="341"/>
        <source>Overwrite if newer</source>
        <translation>Sobrescribir si nuevo</translation>
    </message>
    <message>
        <location filename="../../fileExistsDialog.ui" line="354"/>
        <location filename="../../fileExistsDialog.ui" line="357"/>
        <source>Overwrite if older</source>
        <translation>Sobrescribir si es mayor</translation>
    </message>
</context>
<context>
    <name>fileIsSameDialog</name>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="40"/>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="110"/>
        <source>Modified</source>
        <translation>Modificado</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="70"/>
        <source>File name</source>
        <translation>Nombre de archivo</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="14"/>
        <source>The source and destination are same</source>
        <translation>El origen y el destino son los mismos</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="90"/>
        <source>Folder</source>
        <translation>Carpeta</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="159"/>
        <source>Suggest new &amp;name</source>
        <translation>Sugerir nuevo nombre</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="170"/>
        <source>&amp;Always perform this action</source>
        <translation>&amp;Siempre realice esta acción</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="190"/>
        <source>&amp;Rename</source>
        <translation>Cambiar el nombre</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="197"/>
        <source>&amp;Skip</source>
        <translation>Omitir</translation>
    </message>
    <message>
        <location filename="../../fileIsSameDialog.ui" line="204"/>
        <source>&amp;Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
<context>
    <name>folderExistsDialog</name>
    <message>
        <location filename="../../folderExistsDialog.ui" line="34"/>
        <source>Source</source>
        <translation>Fuente</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="50"/>
        <source>Destination</source>
        <translation>Destino</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="14"/>
        <source>The source and destination is identical</source>
        <translation>La fuente y el destino es idéntica</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="82"/>
        <location filename="../../folderExistsDialog.ui" line="150"/>
        <source>Modified</source>
        <translation>Modificado</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="99"/>
        <location filename="../../folderExistsDialog.ui" line="160"/>
        <source>Folder name</source>
        <translation>Nombre de la carpeta</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="116"/>
        <location filename="../../folderExistsDialog.ui" line="184"/>
        <source>Folder</source>
        <translation>Carpeta</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="227"/>
        <source>Suggest new &amp;name</source>
        <translation>Sugerir nuevo nombre</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="238"/>
        <source>&amp;Always perform this action</source>
        <translation>&amp;Siempre realice esta acción</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="245"/>
        <source>&amp;Rename</source>
        <translation>Cambiar el nombre</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="252"/>
        <source>Merge</source>
        <translation>Unir</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="259"/>
        <source>Skip</source>
        <translation>Omitir</translation>
    </message>
    <message>
        <location filename="../../folderExistsDialog.ui" line="266"/>
        <source>&amp;Cancel</source>
        <translation>Cancelar</translation>
    </message>
</context>
</TS>
